@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: addr.h,v 1.1.1.1 2001/10/11 04:14:48 dugsong Exp $
+ * $Id: addr.h,v 1.5 2001/12/29 21:05:46 dugsong Exp $
  */
 
 #ifndef DNET_ADDR_H
@@ -32,7 +32,9 @@ struct addr {
 #define addr_data16	__addr_u.__data16
 #define addr_data32	__addr_u.__data32
 
+__BEGIN_DECLS
 int	 addr_cmp(struct addr *a, struct addr *b);
+int	 addr_bcast(struct addr *a, struct addr *b);
 
 int	 addr_ntop(struct addr *src, char *dst, size_t size);
 int	 addr_pton(char *src, struct addr *dst);
@@ -46,7 +48,14 @@ int	 addr_ston(struct sockaddr *sa, struct addr *a);
 int	 addr_btos(u_short bits, struct sockaddr *sa);
 int	 addr_stob(struct sockaddr *sa, u_short *bits);
 
-int	 addr_btom(u_short bits, u_int32_t *mask);
-int	 addr_mtob(u_int32_t mask, u_short *bits);
+int	 addr_btom(u_short bits, void *mask, size_t size);
+int	 addr_mtob(void *mask, size_t size, u_short *bits);
+
+#define addr_fill(addr, type, bits, data, len) do {	\
+	(addr)->addr_type = type;			\
+	(addr)->addr_bits = bits;			\
+	memmove((addr)->addr_data8, (char *)data, len);	\
+} while (0)
+__END_DECLS
 
 #endif /* DNET_ADDR_H */
