@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: arp.h,v 1.2 2001/10/30 19:23:26 dugsong Exp $
+ * $Id: arp.h,v 1.6 2001/12/14 15:29:20 dugsong Exp $
  */
 
 #ifndef DNET_ARP_H
@@ -58,6 +58,7 @@ typedef struct arp_handle arp_t;
 
 typedef int (*arp_handler)(struct addr *pa, struct addr *ha, void *arg);
 
+__BEGIN_DECLS
 arp_t	*arp_open(void);
 int	 arp_add(arp_t *a, struct addr *pa, struct addr *ha);
 int	 arp_delete(arp_t *a, struct addr *pa);
@@ -65,19 +66,20 @@ int	 arp_get(arp_t *a, struct addr *pa, struct addr *ha);
 int	 arp_loop(arp_t *a, arp_handler callback, void *arg);
 int	 arp_close(arp_t *a);
 
-#define arp_ethip_fill(h, op, sha, spa, tha, tpa) do {		\
-	struct arp_hdr *fill_arp_p = (struct arp_hdr *)(h);	\
-	struct arp_ethip *fill_ethip_p =			\
-		(struct arp_ethip *)((char *)(h) + ARP_HDR_LEN);\
+#define arp_fill_hdr_ethip(hdr, op, sha, spa, tha, tpa) do {	\
+	struct arp_hdr *fill_arp_p = (struct arp_hdr *)(hdr);	\
+	struct arp_ethip *fill_ethip_p = (struct arp_ethip *)	\
+		((u_char *)(hdr) + ARP_HDR_LEN);		\
 	fill_arp_p->ar_hrd = htons(ARP_HRD_ETH);		\
 	fill_arp_p->ar_pro = htons(ARP_PRO_IP);			\
 	fill_arp_p->ar_hln = ETH_ADDR_LEN;			\
 	fill_arp_p->ar_pln = IP_ADDR_LEN;			\
 	fill_arp_p->ar_op = htons(op);				\
-	memcpy(fill_ethip_p->ar_sha, &(sha), ETH_ADDR_LEN);	\
-	memcpy(fill_ethip_p->ar_spa, &(spa), IP_ADDR_LEN);	\
-	memcpy(fill_ethip_p->ar_tha, &(tha), ETH_ADDR_LEN);	\
-	memcpy(fill_ethip_p->ar_tpa, &(tpa), IP_ADDR_LEN);	\
+	memmove(fill_ethip_p->ar_sha, &(sha), ETH_ADDR_LEN);	\
+	memmove(fill_ethip_p->ar_spa, &(spa), IP_ADDR_LEN);	\
+	memmove(fill_ethip_p->ar_tha, &(tha), ETH_ADDR_LEN);	\
+	memmove(fill_ethip_p->ar_tpa, &(tpa), IP_ADDR_LEN);	\
 } while (0)
+__END_DECLS
 
 #endif /* DNET_ARP_H */
