@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: eth.h,v 1.3 2001/11/12 04:16:33 dugsong Exp $
+ * $Id: eth.h,v 1.7 2001/12/14 15:29:20 dugsong Exp $
  */
 
 #ifndef DNET_ETH_H
@@ -52,15 +52,19 @@ struct eth_hdr {
 
 typedef struct eth_handle eth_t;
 
+__BEGIN_DECLS
 eth_t	*eth_open(char *device);
+int	 eth_get(eth_t *e, eth_addr_t *ea);
+int	 eth_set(eth_t *e, eth_addr_t *ea);
 ssize_t	 eth_send(eth_t *e, const void *buf, size_t len);
 int	 eth_close(eth_t *e);
 
-#define eth_fill(h, dst, src, type) do {			\
+#define eth_fill_hdr(h, dst, src, type) do {			\
 	struct eth_hdr *eth_fill_p = (struct eth_hdr *)(h);	\
-	memcpy(&eth_fill_p->eth_dst, &(dst), ETH_ADDR_LEN);	\
-	memcpy(&eth_fill_p->eth_src, &(src), ETH_ADDR_LEN);	\
+	memmove(&eth_fill_p->eth_dst, &(dst), ETH_ADDR_LEN);	\
+	memmove(&eth_fill_p->eth_src, &(src), ETH_ADDR_LEN);	\
 	eth_fill_p->eth_type = htons(type);			\
 } while (0)
+__END_DECLS
 
 #endif /* DNET_ETH_H */
