@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: intf.h,v 1.1.1.1 2001/10/11 04:14:48 dugsong Exp $
+ * $Id: intf.h,v 1.3 2001/12/14 15:29:20 dugsong Exp $
  */
 
 #ifndef DNET_INTF_H
@@ -22,6 +22,7 @@ typedef struct intf_handle intf_t;
 typedef int (*intf_handler)(char *device, struct addr *addr,
 			int flags, void *arg);
 
+__BEGIN_DECLS
 intf_t	*intf_open(void);
 #ifdef notyet
 /* XXX - need to figure out interface aliases on !BSD */
@@ -32,5 +33,6 @@ int	 intf_set(intf_t *i, char *device, struct addr *addr, int *flags);
 int	 intf_get(intf_t *i, char *device, struct addr *addr, int *flags);
 int	 intf_loop(intf_t *i, intf_handler callback, void *arg); 
 int	 intf_close(intf_t *i);
+__END_DECLS
 
 #endif /* DNET_INTF_H */
