@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: udp.h,v 1.2 2001/10/30 19:23:26 dugsong Exp $
+ * $Id: udp.h,v 1.6 2001/12/14 15:29:20 dugsong Exp $
  */
 
 #ifndef DNET_UDP_H
@@ -22,8 +22,8 @@ struct udp_hdr {
 
 #define UDP_PORT_MAX	65535
 
-#define udp_fill(h, sport, dport, ulen) do {			\
-	struct udp_hdr *udp_fill_p = (struct udp_hdr *)(h);	\
+#define udp_fill_hdr(hdr, sport, dport, ulen) do {		\
+	struct udp_hdr *udp_fill_p = (struct udp_hdr *)(hdr);	\
 	udp_fill_p->uh_sport = htons(sport);			\
 	udp_fill_p->uh_dport = htons(dport);			\
 	udp_fill_p->uh_ulen = htons(ulen);			\
