@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2001 Dug Song <dugsong@monkey.org>
  *
- * $Id: fw-ipfw.c,v 1.7 2001/10/16 15:40:07 dugsong Exp $
+ * $Id: fw-ipfw.c,v 1.9 2001/12/29 21:06:41 dugsong Exp $
  */
 
 #include "config.h"
@@ -15,6 +15,7 @@
 #include <netinet/in.h>
 #include <netinet/ip_fw.h>
 
+#include <assert.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -69,8 +70,8 @@ fr_to_ipfw(struct fw_rule *fr, struct ip_fw *ipfw)
 	ipfw->fw_prot = fr->proto;
 	ipfw->fw_src.s_addr = fr->src.addr_ip;
 	ipfw->fw_dst.s_addr = fr->dst.addr_ip;
-	addr_btom(fr->src.addr_bits, &ipfw->fw_smsk.s_addr);
-	addr_btom(fr->dst.addr_bits, &ipfw->fw_dmsk.s_addr);
+	addr_btom(fr->src.addr_bits, &ipfw->fw_smsk.s_addr, IP_ADDR_LEN);
+	addr_btom(fr->dst.addr_bits, &ipfw->fw_dmsk.s_addr, IP_ADDR_LEN);
 
 	switch (fr->proto) {
 	case IP_PROTO_TCP:
@@ -130,8 +131,8 @@ ipfw_to_fr(struct ip_fw *ipfw, struct fw_rule *fr)
 	fr->src.addr_type = fr->dst.addr_type = ADDR_TYPE_IP;
 	fr->src.addr_ip = ipfw->fw_src.s_addr;
 	fr->dst.addr_ip = ipfw->fw_dst.s_addr;
-	addr_mtob(ipfw->fw_smsk.s_addr, &fr->src.addr_bits);
-	addr_mtob(ipfw->fw_dmsk.s_addr, &fr->dst.addr_bits);
+	addr_mtob(&ipfw->fw_smsk.s_addr, IP_ADDR_LEN, &fr->src.addr_bits);
+	addr_mtob(&ipfw->fw_dmsk.s_addr, IP_ADDR_LEN, &fr->dst.addr_bits);
 
 	switch (fr->proto) {
 	case IP_PROTO_TCP:
@@ -196,10 +197,8 @@ fw_add(fw_t *fw, struct fw_rule *rule)
 {
 	struct ip_fw ipfw;
 	
-	if (fw == NULL || rule == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(fw != NULL && rule != NULL);
+
 	fr_to_ipfw(rule, &ipfw);
 
 	return (setsockopt(fw->fd, IPPROTO_IP, IP_FW_ADD,
@@ -227,10 +226,8 @@ fw_delete(fw_t *fw, struct fw_rule *rule)
 	int nbytes, nalloc, ret;
 	u_char *buf, *new;
 
-	if (rule == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(rule != NULL);
+
 	nbytes = nalloc = sizeof(*ipfw);
 	if ((buf = malloc(nbytes)) == NULL)
 		return (-1);
@@ -313,10 +310,8 @@ fw_loop(fw_t *fw, fw_handler callback, void *arg)
 int
 fw_close(fw_t *fw)
 {
-	if (fw == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(fw != NULL);
+
 	if (close(fw->fd) < 0)
 		return (-1);
 
