@@ -4,7 +4,7 @@
  * Copyright (c) 2001 Dug Song <dugsong@monkey.org>
  * Copyright (c) 1999 Masaki Hirabaru <masaki@merit.edu>
  * 
- * $Id: route-bsd.c,v 1.7 2001/10/27 16:21:20 dugsong Exp $
+ * $Id: route-bsd.c,v 1.9 2001/12/26 16:59:54 dugsong Exp $
  */
 
 #include "config.h"
@@ -34,6 +34,7 @@
 #undef route_t
 #include <netinet/in.h>
 
+#include <assert.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -63,6 +64,16 @@ struct route_handle {
 #endif
 };
 
+#ifdef DEBUG
+static void
+route_msg_print(struct rt_msghdr *rtm)
+{
+	printf("v: %d type: 0x%x flags: 0x%x addrs: 0x%x pid: %d seq: %d\n",
+	    rtm->rtm_version, rtm->rtm_type, rtm->rtm_flags,
+	    rtm->rtm_addrs, rtm->rtm_pid, rtm->rtm_seq);
+}
+#endif
+
 static int
 route_msg(route_t *r, int type, u_char *buf, int buflen,
     struct addr *dst, struct addr *gw)
@@ -76,11 +87,11 @@ route_msg(route_t *r, int type, u_char *buf, int buflen,
 		return (-1);
 	}
 	memset(buf, 0, buflen);
-	
+
 	rtm = (struct rt_msghdr *)buf;
 	rtm->rtm_version = RTM_VERSION;
-	rtm->rtm_type = type;
-	rtm->rtm_flags = RTF_UP;
+	if ((rtm->rtm_type = type) != RTM_DELETE)
+		rtm->rtm_flags = RTF_UP;
 	rtm->rtm_addrs = RTA_DST;
 	rtm->rtm_pid = r->pid;
 	rtm->rtm_seq = ++r->seq;
@@ -109,20 +120,21 @@ route_msg(route_t *r, int type, u_char *buf, int buflen,
 		rtm->rtm_flags |= RTF_HOST;
 	
 	rtm->rtm_msglen = (u_char *)sa - buf;
-
+#ifdef DEBUG
+	route_msg_print(rtm);
+#endif
 #ifdef HAVE_STREAMS_ROUTE
 	if (ioctl(r->fd, RTSTR_SEND, rtm) < 0)
 		return (-1);
 #else
 	if (write(r->fd, buf, rtm->rtm_msglen) < 0)
 		return (-1);
-
-	while ((len = read(r->fd, buf, buflen)) != -1) {
-		if (len < sizeof(*rtm))
+	
+	while (type == RTM_GET && (len = read(r->fd, buf, buflen)) > 0) {
+		if (len < sizeof(*rtm)) {
 			return (-1);
-		
-		if (rtm->rtm_type == type &&
-		    rtm->rtm_pid == r->pid &&
+		}
+		if (rtm->rtm_type == type && rtm->rtm_pid == r->pid &&
 		    rtm->rtm_seq == r->seq) {
 			if (rtm->rtm_errno) {
 				errno = rtm->rtm_errno;
@@ -132,15 +144,16 @@ route_msg(route_t *r, int type, u_char *buf, int buflen,
 		}
 	}
 #endif
-	if (type == RTM_GET && rtm->rtm_addrs & (RTA_DST|RTA_GATEWAY)){
+	if (type == RTM_GET && (rtm->rtm_addrs & (RTA_DST|RTA_GATEWAY)) ==
+	    (RTA_DST|RTA_GATEWAY)) {
 		sa = (struct sockaddr *)(rtm + 1);
 		sa = NEXTSA(sa);
 		
 		if (addr_ston(sa, gw) < 0)
 			return (-1);
-
+		
 		if (gw->addr_type != ADDR_TYPE_IP) {
-			errno = EINVAL;
+			errno = ESRCH;
 			return (-1);
 		}
 	}
@@ -181,10 +194,8 @@ route_add(route_t *r, struct addr *dst, struct addr *gw)
 {
 	u_char buf[BUFSIZ];
 
-	if (dst == NULL || gw == NULL) {
-		errno = EDESTADDRREQ;
-		return (-1);
-	}
+	assert(dst != NULL && gw != NULL);
+
 	if (route_msg(r, RTM_ADD, buf, sizeof(buf), dst, gw) < 0)
 		return (-1);
 	
@@ -197,10 +208,8 @@ route_delete(route_t *r, struct addr *dst)
 	struct addr gw;
 	u_char buf[BUFSIZ];
 	
-	if (dst == NULL) {
-		errno = EDESTADDRREQ;
-		return (-1);
-	}
+	assert(dst != NULL);
+
 	if (route_get(r, dst, &gw) < 0)
 		return (-1);
 	
@@ -215,13 +224,8 @@ route_get(route_t *r, struct addr *dst, struct addr *gw)
 {
 	u_char buf[BUFSIZ];
 	
-	if (dst == NULL) {
-		errno = EDESTADDRREQ;
-		return (-1);
-	} else if (gw == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(dst != NULL && gw != NULL);
+	
 	if (route_msg(r, RTM_GET, buf, sizeof(buf), dst, gw) < 0)
 		return (-1);
 	
@@ -432,10 +436,8 @@ route_loop(route_t *r, route_handler callback, void *arg)
 int
 route_close(route_t *r)
 {
-	if (r == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(r != NULL);
+
 	if (
 #ifdef HAVE_STREAMS_MIB2
 		close(r->ip_fd) < 0 ||
