@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: route-hpux.c,v 1.2 2001/10/19 00:39:08 dugsong Exp $
+ * $Id: route-hpux.c,v 1.4 2001/12/29 21:06:41 dugsong Exp $
  */
 
 #include "config.h"
@@ -15,6 +15,7 @@
 
 #include <net/route.h>
 
+#include <assert.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,10 +47,8 @@ route_add(route_t *r, struct addr *dst, struct addr *gw)
 {
 	struct rtentry rt;
 	
-	if (r == NULL || dst == NULL || gw == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(r != NULL && dst != NULL && gw != NULL);
+
 	memset(&rt, 0, sizeof(rt));
 
 	if (addr_ntos(dst, &rt.rt_dst) < 0 ||
@@ -58,12 +57,12 @@ route_add(route_t *r, struct addr *dst, struct addr *gw)
 
 	if (dst->addr_bits < IP_ADDR_BITS) {
 		rt.rt_flags = RTF_UP | RTF_GATEWAY;
-		if (addr_btom(dst->addr_bits,
-		    (u_int32_t *)&rt.rt_subnetmask) < 0)
+		if (addr_btom(dst->addr_bits, &rt.rt_subnetmask,
+		    IP_ADDR_LEN) < 0)
 			return (-1);
 	} else {
 		rt.rt_flags = RTF_UP | RTF_HOST | RTF_GATEWAY;
-		addr_btom(IP_ADDR_BITS, (u_int32_t *)&rt.rt_subnetmask);
+		addr_btom(IP_ADDR_BITS, &rt.rt_subnetmask, IP_ADDR_LEN);
 	}
 	return (ioctl(r->fd, SIOCADDRT, &rt));
 }
@@ -73,10 +72,8 @@ route_delete(route_t *r, struct addr *dst)
 {
 	struct rtentry rt;
 
-	if (r == NULL || dst == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(r != NULL && dst != NULL);
+
 	memset(&rt, 0, sizeof(rt));
 
 	if (addr_ntos(dst, &rt.rt_dst) < 0)
@@ -84,12 +81,12 @@ route_delete(route_t *r, struct addr *dst)
 
 	if (dst->addr_bits < IP_ADDR_BITS) {
 		rt.rt_flags = RTF_UP;
-		if (addr_btom(dst->addr_bits,
-		    (u_int32_t *)&rt.rt_subnetmask) < 0)
+		if (addr_btom(dst->addr_bits, &rt.rt_subnetmask,
+		    IP_ADDR_LEN) < 0)
 			return (-1);
 	} else {
 		rt.rt_flags = RTF_UP | RTF_HOST;
-		addr_btom(IP_ADDR_BITS, (u_int32_t *)&rt.rt_subnetmask);
+		addr_btom(IP_ADDR_BITS, &rt.rt_subnetmask, IP_ADDR_LEN);
 	}
 	return (ioctl(r->fd, SIOCDELRT, &rt));
 }
@@ -99,15 +96,13 @@ route_get(route_t *r, struct addr *dst, struct addr *gw)
 {
 	struct rtreq rtr;
 
-	if (r == NULL || dst == NULL || gw == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(r != NULL && dst != NULL && gw != NULL);
+
 	memset(&rtr, 0, sizeof(rtr));
 	memcpy(&rtr.rtr_destaddr, &dst->addr_ip, IP_ADDR_LEN);
 	
 	if (dst->addr_bits < IP_ADDR_BITS)
-		addr_btom(dst->addr_bits, (u_int32_t *)&rtr.rtr_subnetmask);
+		addr_btom(dst->addr_bits, &rtr.rtr_subnetmask, IP_ADDR_LEN);
 	
 	if (ioctl(r->fd, SIOCGRTENTRY, &rtr) < 0)
 		return (-1);
@@ -158,7 +153,7 @@ route_loop(route_t *r, route_handler callback, void *arg)
 			continue;
 		
 		dst.addr_ip = rtentries[i].Dest;
-		addr_mtob(rtentries[i].Mask, &dst.addr_bits);
+		addr_mtob(&rtentries[i].Mask, IP_ADDR_LEN, &dst.addr_bits);
 		gw.addr_ip = rtentries[i].NextHop;
 
 		if ((ret = callback(&dst, &gw, arg)) != 0)
@@ -170,10 +165,8 @@ route_loop(route_t *r, route_handler callback, void *arg)
 int
 route_close(route_t *r)
 {
-	if (r == NULL) {
-		errno = EINVAL;
-		return (-1);
-	}
+	assert(r != NULL);
+
 	if (close(r->fd) < 0)
 		return (-1);
 	
